## Установка

Установить через pip:

```bash 
pip install FloriaConsoleGUI --upgrade
```

Или скачать исходный код из [PyPi](https://pypi.org/project/FloriaConsoleGUI/).

## Использование

Примеры использования можно найти в репозитории проекта на [GitHub](https://github.com/FloriaProduction/FloriaConsoleGUI/tree/main/Examples).

## Документация

На данный момент [документация](https://FloriaConsoleGUI.github.io) в разработке.